@@ -68,8 +68,8 @@ def get_tiers_parsers() -> Parsers:
   yield "apply-mapping", "apply mapping table to marks", get_marks_mapping_parser
   yield "transcribe", "transcribe words of tiers using a pronunciation dictionary", get_transcription_parser
   yield "remove", "remove tiers", get_tiers_removing_parser
-  yield "remove-symbols", "remove symbols from tiers", get_symbol_removing_parser
-  yield "mark-silence", "mark silence intervals", get_label_silence_parser
+  # yield "remove-symbols", "remove symbols from tiers", get_symbol_removing_parser
+  # yield "mark-silence", "mark silence intervals", get_label_silence_parser
 
 
 def get_tier_parsers() -> Parsers:
@@ -93,7 +93,7 @@ def get_intervals_parsers() -> Parsers:
   yield "fix-boundaries", "align boundaries of tiers according to a reference tier", get_boundary_fixing_parser
   yield "remove", "remove intervals", get_intervals_removing_parser
   yield "plot-durations", "plot durations", get_plot_interval_durations_parser
-  yield "join-between-pauses", "join intervals between pauses (LEGACY, please use join-between-marks)", get_between_pause_joining_parser
+  # yield "join-between-pauses", "join intervals between pauses (LEGACY, please use join-between-marks)", get_between_pause_joining_parser
   yield "replace-text", "replace text using regex pattern", get_text_replacement_parser
 
 
@@ -156,9 +156,10 @@ def parse_args(args: List[str]) -> None:
 
   try:
     ns = parser.parse_args(args)
-  except SystemExit:
-    # invalid command supplied
-    return
+  except SystemExit as error:
+    error_code = error.args[0]
+    # -v -> 0; invalid arg -> 2
+    sys.exit(error_code)
 
   if hasattr(ns, INVOKE_HANDLER_VAR):
     invoke_handler: Callable[..., ExecutionResult] = getattr(ns, INVOKE_HANDLER_VAR)
@@ -212,8 +213,12 @@ def parse_args(args: List[str]) -> None:
     if log_to_file:
       logger.info(f"Written log to: {ns.log.absolute()}")
 
+    if not success:
+      sys.exit(1)
+    sys.exit(0)
   else:
     parser.print_help()
+    sys.exit(0)
 
 
 def run():
