@@ -1,8 +1,10 @@
+from textgrid_tools_cli.intervals.between_marks_joining import get_between_marks_joining_parser
 from textgrid_tools_cli.intervals.between_pause_joining import get_between_pause_joining_parser
 from textgrid_tools_cli.intervals.boundary_fixing import get_boundary_fixing_parser
 from textgrid_tools_cli.intervals.boundary_joining import get_boundary_joining_parser
 from textgrid_tools_cli.intervals.duration_joining import get_duration_joining_parser
 from textgrid_tools_cli.intervals.durations_plotting import get_plot_interval_durations_parser
+from textgrid_tools_cli.intervals.joining import get_joining_parser
 from textgrid_tools_cli.intervals.mark_joining import get_mark_joining_parser
 from textgrid_tools_cli.intervals.removing import get_removing_parser
 from textgrid_tools_cli.intervals.splitting import get_splitting_parser
