@@ -6,10 +6,10 @@ from textgrid_tools.validation import NonDistinctTiersError
 from textgrid_tools_cli.common import process_grids_mp
 from textgrid_tools_cli.globals import ExecutionResult
 from textgrid_tools_cli.helper import (add_chunksize_argument, add_directory_argument,
-                                       add_encoding_argument, add_maxtaskperchild_argument,
-                                       add_n_jobs_argument, add_output_directory_argument,
-                                       add_overwrite_argument, add_tier_argument,
-                                       parse_non_empty_or_whitespace)
+                                       add_dry_run_argument, add_encoding_argument,
+                                       add_maxtaskperchild_argument, add_n_jobs_argument,
+                                       add_output_directory_argument, add_overwrite_argument,
+                                       add_tier_argument, parse_non_empty_or_whitespace)
 from textgrid_tools_cli.logging_configuration import init_and_get_console_logger
 
 
@@ -17,7 +17,7 @@ def get_renaming_parser(parser: ArgumentParser):
   parser.description = "This command renames a tier."
   add_directory_argument(parser)
   add_tier_argument(parser, "tier which should be renamed")
-  parser.add_argument("name", type=parse_non_empty_or_whitespace, metavar="tier",
+  parser.add_argument("name", type=parse_non_empty_or_whitespace, metavar="NEW-NAME",
                       help="new name of tier")
   add_encoding_argument(parser)
   add_output_directory_argument(parser)
@@ -25,6 +25,7 @@ def get_renaming_parser(parser: ArgumentParser):
   add_n_jobs_argument(parser)
   add_chunksize_argument(parser)
   add_maxtaskperchild_argument(parser)
+  add_dry_run_argument(parser)
   return app_rename_tier
 
 
@@ -42,4 +43,4 @@ def app_rename_tier(ns: Namespace) -> ExecutionResult:
     output_tier_name=ns.name,
   )
 
-  return process_grids_mp(ns.directory, ns.encoding, ns.output_directory, ns.overwrite, method, ns.chunksize, ns.n_jobs, ns.maxtasksperchild)
+  return process_grids_mp(ns.directory, ns.encoding, ns.output_directory, ns.overwrite, method, ns.chunksize, ns.n_jobs, ns.maxtasksperchild, ns.dry)
